<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://thegetsmartgroup.com
 * @since      1.0.0
 *
 * @package    Latham_Liners
 * @subpackage Latham_Liners/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Latham_Liners
 * @subpackage Latham_Liners/public
 * @author     Get Smart Group <plugins@thegetsmartgroup.com>
 */
 
 
 use OpenCloud\Rackspace;
 //use Dotenv\Dotenv;
 

class Latham_Liners_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
	
	
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		

	}

			/**
			 * Register the stylesheets for the public-facing side of the site.
			 *
			 * @since    1.0.0
			 */
			public function enqueue_styles() {

				/**
				 * This function is provided for demonstration purposes only.
				 *
				 * An instance of this class should be passed to the run() function
				 * defined in Latham_Liners_Loader as all of the hooks are defined
				 * in that particular class.
				 *
				 * The Latham_Liners_Loader will then create the relationship
				 * between the defined hooks and the functions defined in this
				 * class.
				 */

				wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/public.min.css', array(), $this->version, 'all' );

			}

			/**
			 * Register the JavaScript for the public-facing side of the site.
			 *
			 * @since    1.0.0
			 */
			public function enqueue_scripts() {

					/**
					 * This function is provided for demonstration purposes only.
					 *
					 * An instance of this class should be passed to the run() function
					 * defined in Latham_Liners_Loader as all of the hooks are defined
					 * in that particular class.
					 *
					 * The Latham_Liners_Loader will then create the relationship
					 * between the defined hooks and the functions defined in this
					 * class.
					 */
					wp_enqueue_script('jquery');
					wp_enqueue_script( $this->plugin_name . '-materialize', plugin_dir_url( __FILE__ ) . 'js/materialize.js',  true );
					wp_enqueue_script( $this->plugin_name . '-steps', plugin_dir_url( __FILE__ ) . 'js/jquery.smartWizard.js', array( 'jquery' ), $this->version, true ); 
					wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/latham-liners-public.min.js', array( 'jquery' ), $this->version, true );

			}

			public function rs_client_auth() {
					$rs_api_user_name = 'linerpluginuser';
					$rs_api_key = '4c77705fcec24677be56fd9c0ae12c8d';
					
					
					$client = new Rackspace(
							Rackspace::US_IDENTITY_ENDPOINT, [
								  'username' => $rs_api_user_name,
								  'apiKey'   => $rs_api_key,
							]
					);
          /*
          $transient = get_transient( 'rs_auth_cache' );
          
					if ( $transient !== false ) {
					    $client->importCredentials(  $transient  );
					}
          
*/
					$token = $client->getToken();

					// If no token exists, or the current token is expired, re-authenticate and save the new token to disk
          /*

					if (!$token) {
              set_transient( 'rs_auth_cache', $client->exportCredentials(), 60 * MINUTE_IN_SECONDS );
							//file_put_contents($cacheFile, serialize($client->exportCredentials()));
					}
          */
          $client->authenticate();
          //$client = wp_json_encode($client);
					return $client;
			}
			
                    
			
			public function rs_get_thumbnails() {
        
        $client = $this->rs_client_auth();
        $token = $client->getToken();
      
        $container_args = array(
                'method' => 'GET',
                'headers' => array(
                  'Accept' => 'application/json',
                  //'lathampool' => $rs_api_key
                  'X-Auth-Token' => $token
                )
        );
        $cdn_url = 'https://905d121a9e6319413f2e-7528d0539499b29f01f854833af2001a.ssl.cf5.rackcdn.com';
        $thumbnail_container_url = 'https://storage101.iad3.clouddrive.com/v1/MossoCloudFS_1205497/Latham?format=json&path=latham-images/thumbs';
        //$thumbnail_container_url = 'https://iad.feeds.api.rackspacecloud.com/v1/MossoCloudFS_1205497/Latham?format=json&path=latham-images/thumbs';
        
        $thumbnail_container_response = wp_remote_get( $thumbnail_container_url, $container_args );
        $thumb_api_response = json_decode( wp_remote_retrieve_body( $thumbnail_container_response ), true );
        
					$thumbs_decoded = array();
        
          
          foreach($thumb_api_response as $value)
          {
            $thumbs_decoded[] .= $value['name'];
          }
          
					//echo '<pre>';
					//echo var_dump($thumbs_decoded);
					//echo '</pre>';
          
          return $thumbs_decoded;
			}
      
			
			
			
			
			

			/**
			 * Enqueue scripts separately below to place in the header.
			 *
			 * @since    1.0.0
			 */
			public function enqueue_header_scripts() {
				 	wp_enqueue_script( $this->plugin_name . '-lozad', 'https://cdn.jsdelivr.net/npm/lozad/dist/lozad.min.js', $this->version,  false );
					wp_enqueue_script( $this->plugin_name . '-canvi', plugin_dir_url( __FILE__ ) . 'js/canvi.js', $this->version, true ); 
			}
			
			public static function get_assets_listing($dir) {
					
					// Define empty array
					$files_arr = '';
					
					/**
					 * DEVNOTE-- remove pretty print before deployment
					 */
			 		// Encode the array returned from scandir() results in JSON format
					$files_arr .= json_encode($scan_dir_array, JSON_PRETTY_PRINT, JSON_FORCE_OBJECT);
					
					// Return our directory listing 
					return $files_arr;
				
			}
			
			
			public function diplay_liner_configurator() {
					$public_display = plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/latham-liners-public-display.php';
					
					ob_start(); 
					require $public_display; 
					return ob_get_clean();
			}
			
			

			public function register_shortcodes() {
		    	add_shortcode( 'latham_liners', array( $this, 'diplay_liner_configurator') );
			}
			
			/**
		     * Retrieves a template part
		     *
		     * @since v1.5
		     *
		     * Taken from bbPress
		     *
		     * @param string $slug
		     * @param string $name Optional. Default null
		     *
		     * @uses  rcp_locate_template()
		     * @uses  load_template()
		     * @uses  get_template_part()
		     */
		    public static function liner_configurator_get_template($slug, $name = null, $load = true) {
		        // Execute code for this part
		        do_action('get_template_part_' . $slug, $slug, $name);

		        // Setup possible parts
		        $templates = array();
		        if (isset($name))
		            $templates[] = $slug . '-' . $name . '.php';
		        $templates[] = $slug . '.php';

		        // Allow template parts to be filtered
		        $templates = apply_filters('rcp_get_template_part', $templates, $slug, $name);

		        // Return the part that is found

		        return Latham_Liners_Public::liner_configurator_locate_template($templates, $load, false);
		    }
				
				
				
				/**
		     * Retrieve the name of the highest priority template file that exists.
		     *
		     * Searches in the STYLESHEETPATH before TEMPLATEPATH so that themes which
		     * inherit from a parent theme can just overload one file. If the template is
		     * not found in either of those, it looks in the theme-compat folder last.
		     *
		     * Taken from bbPress
		     *
		     * @since v1.5
		     *
		     * @param string|array $template_names Template file(s) to search for, in order.
		     * @param bool $load If true the template file will be loaded if it is found.
		     * @param bool $require_once Whether to require_once or require. Default true.
		     *                            Has no effect if $load is false.
		     * @return string The template filename if one is located.
		     */
		    public static function liner_configurator_locate_template($template_names, $load = false, $require_once = true) {
		        // No file found yet
		        $located = false;

		        // Try to find a template file
		        foreach ((array) $template_names as $template_name) {

		            // Continue if template is empty
		            if (empty($template_name))
		                continue;

		            // Trim off any slashes from the template name
		            $template_name = ltrim($template_name, '/');

		            // Check child theme first
		            if (file_exists(trailingslashit(get_stylesheet_directory()) . 'partials/' . $template_name)) {
		                $located = trailingslashit(get_stylesheet_directory()) . 'partials/' . $template_name;
		                break;

		                // Check parent theme next
		            } elseif (file_exists(trailingslashit(get_template_directory()) . 'partials/' . $template_name)) {
		                $located = trailingslashit(get_template_directory()) . 'partials/' . $template_name;
		                break;

		                // Check theme compatibility last
		            } elseif (file_exists(trailingslashit(Latham_Liners_Public::latham_liners_get_template_dir()) . $template_name)) {
		                $located = trailingslashit(Latham_Liners_Public::latham_liners_get_template_dir()) . $template_name;
		                break;
		            }
		        }

		        if (( true == $load ) && !empty($located))
		            load_template($located, $require_once);

		        return $located;
		    }



		    public static function latham_liners_get_template_dir() {
					
		        $path = plugin_dir_path( __FILE__ );
		        return $path.'/partials';
						
		    }

			
		        

		}
